@@ -1,5 +1,7 @@
 # transforms
 from .byol_transforms import BYOLTransform0, BYOLTransform1
+from .imagenet_minaug_transforms import ImagenetMinaugTransform
+from .imagenet_noaug_transforms import ImagenetNoaugTransform
 from .mae_finetune_transform import MAEFinetuneTransform
 # norm
 from .norm.kd_cifar10_norm import KDCifar10Norm
